# randword

The Python package for generating random English words

## Table of contents

- [Installation](#installation)
- [Usage](#usage)
- [Credits and references](#credits-and-references)
- [License](#license)

## Installation

You can install `randword` package using `pip` or `easy_install`:

```bash
pip install randword
```

```bash
easy_install randword
```

You can also just clone the repository and run:

```bash
python setup.py install
```

## Usage

See the [documentation](https://randword.readthedocs.io/en/stable/index.html).

## Credits and references

- A database of words for each part of the speech was taken from [WordNet](https://wordnet.princeton.edu/).
- Splitting words into different parts of speech is made possible by [Chilli's answer](https://stackoverflow.com/a/27415226/13692774) on [Stack Overflow](https://stackoverflow.com/).
- Surnames database was taken from this [GitHub repo](https://github.com/arineng/arincli/blob/master/lib/last-names.txt).
- Male and females names were taken from the [website of Carnegie Mellon University](https://www.cs.cmu.edu/afs/cs/project/ai-repository/ai/areas/nlp/corpora/names/).
- Countries database was taken from [this GitHub gist](https://gist.github.com/kalinchernev/486393efcca01623b18d).
- Cities database was taken from [this GitHub gist](https://gist.github.com/norcal82/4accc0d968444859b408).
- Magic 8-Ball answers were taken from [Wikipedia page](https://en.wikipedia.org/wiki/Magic_8-Ball).

## License

[randword](https://github.com/8nhuman8/randword) specific code is distributed under [MIT License](https://github.com/8nhuman8/randword/blob/master/LICENSE.txt).

Copyright (c) 2022 Artyom Bezmenov
